Build the agent_reference object used to run a stored Azure AI Foundry
agent through foundry_response(). Pass the resulting object (or simply the
agent name) to the agent argument of foundry_response().
Build the agent_reference object used to run a stored Azure AI Foundry
agent through foundry_response(). Pass the resulting object (or simply the
agent name) to the agent argument of foundry_response().