foundry_get_token: Get Azure AI Foundry Bearer Token

View source: R/auth.R

foundry_get_tokenR Documentation

Get Azure AI Foundry Bearer Token

Description

Retrieve a bearer token from the environment or a provided value.

Usage

foundry_get_token(
  token = NULL,
  required = FALSE,
  scope = c("resource", "project")
)

Arguments

token

Character. Optional token to use instead of environment variables.

required

Logical. If TRUE, throws an error when no token is found.

scope

Character. Endpoint family for the token.

Value

The bearer token string, or NULL if not found and not required.


foundryR documentation built on Sept. 25, 2026, 1:10 a.m.