warn_if_chat_model: Warn if Model Looks Like a Chat Model

View source: R/utils.R

warn_if_chat_modelR Documentation

Warn if Model Looks Like a Chat Model

Description

Internal function to warn users if they appear to be using a chat model for embedding operations.

Usage

warn_if_chat_model(model, calling_fn = "foundry_embed")

Arguments

model

Character. The model/deployment name.

calling_fn

Character. The function name for the warning message.

Value

NULL (invisibly). Called for side effect of warning.


foundryR documentation built on Sept. 25, 2026, 1:10 a.m.