| foundry_file_download | R Documentation |
Download Microsoft Foundry file content
foundry_file_download(
file_id,
path,
overwrite = FALSE,
api_key = NULL,
token = NULL,
endpoint = NULL,
api_version = NULL
)
file_id |
Character. File ID to download. |
path |
Character. Local path where the file content should be written. |
overwrite |
Logical. Whether to overwrite an existing file. |
api_key |
Character. Optional API key override. |
token |
Character. Optional bearer token override. |
endpoint |
Character. Optional endpoint override. |
api_version |
Character. Optional API version query value. |
A tibble with the local path, number of bytes written, and file ID.
## Not run:
# Requires a configured Azure endpoint, credentials, and an uploaded file ID.
local({
path <- tempfile(fileext = ".jsonl")
on.exit(unlink(path))
foundry_file_download("file_abc123", path)
})
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.