| foundry_grader_score_model | R Documentation |
Use a model to assign a numeric score to each row. Rows at or above
pass_threshold pass. Scores fall within range, which defaults to
c(0, 1).
foundry_grader_score_model(
name,
model,
input,
pass_threshold = NULL,
range = NULL
)
name |
Character. Grader name. |
model |
Character. Deployment name of the scoring model. |
input |
List. A list of items from |
pass_threshold |
Numeric. Optional score at or above which a row passes. |
range |
Numeric vector of length 2. Optional score range. Defaults to
|
A named list describing a score_model grader.
foundry_grader_score_model(
name = "helpfulness",
model = "gpt-5-nano",
input = list(
foundry_eval_item("Rate helpfulness 0-1: {{sample.output_text}}")
),
pass_threshold = 0.7
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.