Analyze an image for harmful content with Azure AI Content Safety. image
can be a local file path or an HTTPS Azure Blob Storage URL.
Arguments
- image
Character. Local image path or HTTPS Azure Blob Storage URL.
- categories
Character vector of harm categories.
- output_type
Character. Severity level granularity.
- endpoint
Character. Optional Content Safety endpoint.
- api_key
Character. Optional Content Safety key.
- api_version
Character. API version. Defaults to
"2024-09-01".