| foundry_provenance | R Documentation |
Create a one-row tibble that records the model, schema hash, package version, and timestamp for a reproducible annotation run.
foundry_provenance(model, schema, metadata = NULL)
model |
Character. Model or deployment name. |
schema |
List. JSON Schema object. |
metadata |
List. Optional additional metadata. |
A one-row tibble.
schema <- foundry_schema(label = schema_string())
foundry_provenance(
model = "gpt-5-nano",
schema = schema,
metadata = list(run = "pilot")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.