| foundry_response_cancel | R Documentation |
Cancel a background Responses API response
foundry_response_cancel(
response_id,
api_key = NULL,
endpoint = NULL,
project_endpoint = NULL
)
response_id |
Character. The response ID to retrieve. |
api_key |
Character. Optional API key override. |
endpoint |
Character. Optional resource endpoint override. |
project_endpoint |
Character. Optional project endpoint override. Supply this for a response created through the project-scoped API. |
A one-row tibble parsed like foundry_response().
## Not run:
# Requires a configured Azure endpoint and credentials, and the ID of
# an existing background response that can be cancelled.
foundry_response_cancel("resp_abc123")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.