| foundry_response_retrieve | R Documentation |
Retrieve a stored Responses API response
foundry_response_retrieve(
response_id,
api_key = NULL,
endpoint = NULL,
project_endpoint = NULL
)
response_id |
Character. The response ID to retrieve. |
api_key |
Character. Optional API key override. |
endpoint |
Character. Optional resource endpoint override. |
project_endpoint |
Character. Optional project endpoint override. Supply this for a response created through the project-scoped API. |
A one-row tibble parsed like foundry_response().
## Not run:
# Requires a configured Azure endpoint, credentials, and AZURE_FOUNDRY_MODEL.
# The agent example also needs a project endpoint and an existing my-agent.
response <- foundry_response("Hello")
foundry_response_retrieve(response$response_id)
agent_response <- foundry_response("Hello", agent = "my-agent")
foundry_response_retrieve(
agent_response$response_id,
project_endpoint = foundry_get_project_endpoint()
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.