Create a strict object schema for structured outputs. All supplied fields are required by default and additional properties are disabled by default, matching the strict schema shape expected by Azure OpenAI structured outputs.
Examples
schema <- foundry_schema(
sentiment = schema_enum(c("positive", "negative", "neutral")),
score = schema_number()
)