| foundry_set_content_safety_key | R Documentation |
Set or update your Azure Content Safety API key for authentication. The key can be obtained from the Azure Portal under your Content Safety resource.
foundry_set_content_safety_key(key = NULL, store = FALSE)
key |
Character string containing your API key, or NULL to set interactively. If NULL in an interactive session, will prompt for input. |
store |
Logical. If |
Invisibly returns TRUE if key was set successfully.
withr::with_envvar(c(AZURE_CONTENT_SAFETY_KEY = NA_character_), {
foundry_set_content_safety_key("example-key-not-a-secret")
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.