| foundry_set_project_endpoint | R Documentation |
Set the project endpoint used by project-scoped Foundry APIs such as Azure evaluators and Agent Service operations. Prefer copying the full endpoint from the Foundry portal because Azure's project endpoint shape can vary by service generation.
foundry_set_project_endpoint(endpoint, store = FALSE)
endpoint |
Character string containing the project endpoint URL. |
store |
Logical. If |
Invisibly returns TRUE if the endpoint was set successfully.
withr::with_envvar(c(AZURE_FOUNDRY_PROJECT_ENDPOINT = NA_character_), {
foundry_set_project_endpoint(
"https://example.services.ai.azure.com/api/projects/demo"
)
foundry_get_project_endpoint()
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.