| foundry_set_token_provider | R Documentation |
Register a function that returns a Microsoft Entra ID bearer token when foundryR needs to authenticate without an API key. This is useful for long polling jobs and keyless production environments where tokens should be refreshed automatically.
foundry_set_token_provider(provider, scope = c("resource", "project"))
provider |
Function or |
scope |
Character. Endpoint family that the provider authenticates:
|
Invisibly returns the previous provider.
local({
old <- foundry_set_token_provider(foundry_token_azure_cli())
on.exit(foundry_set_token_provider(old))
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.