| foundry_transcribe | R Documentation |
Transcribe audio through the Speech in Foundry Tools LLM Speech API, including MAI-Transcribe models, or through the Azure OpenAI v1 preview audio endpoint.
foundry_transcribe(
file,
model = NULL,
service = c("speech", "openai"),
api = c("v1", "deployment"),
locales = NULL,
language = NULL,
prompt = NULL,
transcribe_style = NULL,
phrase_list = NULL,
response_format = NULL,
timestamp_granularities = NULL,
include = NULL,
temperature = NULL,
api_key = NULL,
token = NULL,
endpoint = NULL,
api_version = NULL
)
file |
Character. Local audio file path. |
model |
Character. Model or deployment name. Defaults to
|
service |
Character. |
api |
Character. Used when |
locales |
Character vector. Optional Speech locale hints such as
|
language |
Character. Optional OpenAI transcription language hint such as
|
prompt |
Character vector. Optional prompt instructions. |
transcribe_style |
Character. Optional MAI-Transcribe 1.5 style, such as
|
phrase_list |
Character vector. Optional phrases for MAI-Transcribe 1.5. |
response_format |
Character. Optional OpenAI response format. |
timestamp_granularities |
Character vector. Optional OpenAI timestamp
granularities, such as |
include |
Character vector. Optional OpenAI include values. |
temperature |
Numeric. Optional OpenAI sampling temperature. |
api_key |
Character. Optional API key override. |
token |
Character. Optional bearer token override. |
endpoint |
Character. Optional endpoint override. |
api_version |
Character. Optional API version. Defaults to
|
A one-row tibble with transcript text, phrase-level detail, and the raw response in list-columns.
## Not run:
# Requires configured Azure Speech/OpenAI endpoints and credentials,
# the corresponding models, and your own local audio input files.
foundry_transcribe("interview.mp3", model = "mai-transcribe-1.5")
foundry_transcribe("interview.mp3", service = "openai", model = "gpt-4o-transcribe")
foundry_transcribe(
"speech.wav", service = "openai", model = "whisper", api = "deployment"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.