| get_content_safety_key | R Documentation |
Retrieve the Content Safety API key from the environment or a provided value. This is primarily an internal function used by other foundryR functions.
get_content_safety_key(key = NULL, required = FALSE)
key |
Character. Optional key to use instead of environment variable. |
required |
Logical. If TRUE, throws an error when no key is found. |
The API key string, or NULL if not found and not required.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.