| warn_if_chat_model | R Documentation |
Internal function to warn users if they appear to be using a chat model for embedding operations.
warn_if_chat_model(model, calling_fn = "foundry_embed")
model |
Character. The model/deployment name. |
calling_fn |
Character. The function name for the warning message. |
NULL (invisibly). Called for side effect of warning.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.